# set max parallel build nodes
%global _smp_ncpus_max 12

Name:           vcmi
Version:        1.6.8
Release:        %mkrel 1
Summary:        Open-source reimplementation and extension of the Heroes III game engine
Group:          Games/Strategy
License:        GPLv2+
URL:            https://www.vcmi.eu/
Source0:        https://github.com/vcmi/vcmi/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  cmake(TBB)
BuildRequires:  pkgconfig(luajit)
BuildRequires:  pkgconfig(fuzzylite)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Help)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(zlib)

%description
VCMI is an open-source project aiming to reimplement the Heroes of Might and
Magic III: In the Wake of Gods game engine, giving it new and extended
possibilities.

To play Heroes III, you will need a copy of the original game.
See VCMI's wiki for Heroes III installation instructions:
https://wiki.vcmi.eu/index.php?title=Installation_on_Linux#Installing_Heroes_III_data_files

%files
%doc ChangeLog.md
%{_datadir}/applications/%{name}*.desktop
%{_iconsdir}/hicolor/*/apps/%{name}client.png
%{_iconsdir}/hicolor/*/apps/%{name}editor.png
%{_iconsdir}/hicolor/scalable/apps/%{name}client.svg
%{_libdir}/%{name}/
%{_gamesbindir}/%{name}*
%{_gamesdatadir}/%{name}/
%{_metainfodir}/eu.vcmi.VCMI.metainfo.xml

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%cmake_qt6 \
       -DBIN_DIR=games \
       -DDATA_DIR=share/games/%{name} \
       -DCMAKE_INSTALL_RPATH_USE_LINK_PATH=ON \
       -DCMAKE_INSTALL_RPATH=%{_libdir}/%{name} \
       -DFORCE_BUNDLED_FL=OFF \
       -DENABLE_TEST=OFF \
       -DENABLE_INNOEXTRACT=OFF
%cmake_build

%install
%cmake_install


%changelog
* Tue May 20 2025 daviddavid <daviddavid> 1.6.8-1.mga10
+ Revision: 2185040
- new version: 1.6.8

* Mon Feb 10 2025 daviddavid <daviddavid> 1.6.5-1.mga10
+ Revision: 2146523
- new version: 1.6.5
+ wally <wally>
- rebuild for boost 1.87.0

* Sun Dec 08 2024 daviddavid <daviddavid> 1.5.7-2.mga10
+ Revision: 2122660
- rebuild for new ffmpeg 7.1

* Fri Sep 13 2024 daviddavid <daviddavid> 1.5.7-1.mga10
+ Revision: 2095693
- new version: 1.5.7
- add archlinux patch to fix build with boost 1.86
+ wally <wally>
- rebuild for boost 1.86.0

* Thu Aug 15 2024 daviddavid <daviddavid> 1.5.6-1.mga10
+ Revision: 2086661
- new version: 1.5.6

* Sun Jul 28 2024 daviddavid <daviddavid> 1.5.5-1.mga10
+ Revision: 2082771
- new version: 1.5.5

* Thu Jun 27 2024 daviddavid <daviddavid> 1.5.3-1.mga10
+ Revision: 2077384
- new version: 1.5.3

* Wed Jun 19 2024 wally <wally> 1.5.2-1.mga10
+ Revision: 2075602
- new version 1.5.2
- rebuild for boost 1.85.0

* Sun Jan 28 2024 daviddavid <daviddavid> 1.3.2-3.mga10
+ Revision: 2035691
- rebuild for tbb 2021.11.0

* Fri Jan 12 2024 wally <wally> 1.3.2-2.mga10
+ Revision: 2030607
- rebuild for boost 1.84.0

* Tue Oct 24 2023 daviddavid <daviddavid> 1.3.2-1.mga10
+ Revision: 2000770
- new version: 1.3.2

* Sun Oct 15 2023 wally <wally> 1.1.1-3.mga10
+ Revision: 1997000
- rebuild for minizip from minizip-ng

* Wed Sep 27 2023 wally <wally> 1.1.1-2.mga10
+ Revision: 1991511
- rebuild for boost 1.83.0

* Thu Feb 09 2023 daviddavid <daviddavid> 1.1.1-1.mga9
+ Revision: 1939568
- new version: 1.1.1

* Wed Jan 18 2023 daviddavid <daviddavid> 1.1.0-2.mga9
+ Revision: 1934251
- switch to Qt6

* Wed Jan 18 2023 daviddavid <daviddavid> 1.1.0-1.mga9
+ Revision: 1934233
- new version: 1.1.0
- re-enable ffmpeg support

* Sat Dec 24 2022 wally <wally> 1.0.0-2.mga9
+ Revision: 1926539
- rebuild for boost 1.81.0

* Fri Sep 30 2022 papoteur <papoteur> 1.0.0-1.mga9
+ Revision: 1893458
- new 1.0.0
- Disable ffmpeg usage (video)
+ wally <wally>
- rebuild for boost 1.79.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Sun Dec 19 2021 wally <wally> 0.99-12.20210131.5.mga9
+ Revision: 1762676
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 0.99-12.20210131.4.mga9
+ Revision: 1744712
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 0.99-12.20210131.3.mga9
+ Revision: 1723029
- rebuild for boost 1.76.0

* Fri Feb 05 2021 akien <akien> 0.99-12.20210131.2.mga8
+ Revision: 1674916
- Use (absolute) RPATH to locate library

* Thu Feb 04 2021 akien <akien> 0.99-12.20210131.1.mga8
+ Revision: 1674866
- Git snapshot from 20210131, as 0.99 stable no longer builds
+ wally <wally>
- build with new cmake macros
- add upstream patch to not wipe out $$HOME when mod unistall fails
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 0.99-10.mga7
+ Revision: 1301573
- Mageia 7 Mass Rebuild

* Fri Apr 27 2018 daviddavid <daviddavid> 0.99-9.mga7
+ Revision: 1222802
- rebuild for new ffmpeg 4.0

* Fri Mar 23 2018 daviddavid <daviddavid> 0.99-8.mga7
+ Revision: 1211530
- add fedora patch to fix build with boost 1.66
+ wally <wally>
- rebuild for new boost

* Tue Nov 21 2017 tv <tv> 0.99-7.mga7
+ Revision: 1178075
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 0.99-6.mga7
+ Revision: 1154576
- rebuild with latest boost

* Sat May 27 2017 neoclust <neoclust> 0.99-5.mga6
+ Revision: 1105083
- Rebuild for ARM

* Tue May 02 2017 akien <akien> 0.99-4.mga6
+ Revision: 1098380
- Rebuild for ffmpeg 3.3
- Rebuild for fuzzylite 6.0

* Wed Mar 08 2017 akien <akien> 0.99-2.mga6
+ Revision: 1090260
- Rebuild for ffmpeg 3.2.4

* Thu Nov 03 2016 akien <akien> 0.99-1.mga6
+ Revision: 1065026
- Version 0.99

* Tue Jan 12 2016 akien <akien> 0.98-5.20160110.1.mga6
+ Revision: 922248
- Build a dev snapshot to try to bypass boost/stl conflict
+ daviddavid <daviddavid>
- rebuild for new boost 1.60.0

* Sun Sep 27 2015 fwang <fwang> 0.98-3.mga6
+ Revision: 884095
- rebuild for new boost

* Thu Aug 13 2015 daviddavid <daviddavid> 0.98-1.mga6
+ Revision: 864515
- new version: 0.98
- update Source URL
- add upstream patch to fix building with Boost 1.58
  * https://github.com/vcmi/vcmi/commit/aa00fdbd0e99b2beec382c7677a64d962b748dcb
- rebuild for new boost-1.58.0

* Fri Nov 14 2014 akien <akien> 0.97-2.mga5
+ Revision: 797012
- Rebuild for ffmpeg 2.4

* Sun Nov 02 2014 akien <akien> 0.97-1.mga5
+ Revision: 795283
- Version 0.97
- Now uses SDL2
- Limit parallel build to prevent compiler crash
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.96-2.mga5
+ Revision: 690137
- Mageia 5 Mass Rebuild

* Mon Jul 14 2014 akien <akien> 0.96-1.mga5
+ Revision: 651795
- Version 0.96

* Sun Mar 23 2014 akien <akien> 0.95-5.mga5
+ Revision: 607041
- CMAKE_INSTALL_LIBDIR has to be a relative path for CMakeLists.txt

* Sun Mar 23 2014 akien <akien> 0.95-4.mga5
+ Revision: 606731
- Undefine rpath skipping (needed so that the libs can be linked)

* Sat Mar 22 2014 akien <akien> 0.95-3.mga5
+ Revision: 606628
- Specify library location

* Sat Mar 22 2014 akien <akien> 0.95-2.mga5
+ Revision: 606553
- Put the runtime libraries in %%_libdir, it seems they cannot be found in %%_libexecdic

* Fri Mar 21 2014 akien <akien> 0.95-1.mga5
+ Revision: 606414
- imported package vcmi

